@@ -21,9 +21,21 @@ extensions = ['sphinx.ext.autodoc',
               'sphinxcontrib.pecanwsme.rest',
               'sphinxcontrib.seqdiag',
               'wsmeext.sphinxext',
-              'oslosphinx',
+              'oslo_config.sphinxconfiggen',
+              'oslo_policy.sphinxpolicygen',
               ]
 
+try:
+    import openstackdocstheme
+    extensions.append('openstackdocstheme')
+except ImportError:
+    openstackdocstheme = None
+
+repository_name = 'openstack/ironic'
+bug_project = 'ironic'
+bug_tag = ''
+html_last_updated_fmt = '%Y-%m-%d %H:%M'
+
 wsme_protocols = ['restjson']
 
 # autodoc generation is a bit aggressive and a nuisance when doing heavy
@@ -43,6 +55,12 @@ master_doc = 'index'
 project = u'Ironic'
 copyright = u'OpenStack Foundation'
 
+config_generator_config_file = '../../tools/config/ironic-config-generator.conf'
+sample_config_basename = '_static/ironic'
+
+policy_generator_config_file = '../../tools/policy/ironic-policy-generator.conf'
+sample_policy_basename = '_static/ironic'
+
 # The version info for the project you're documenting, acts as replacement for
 # |version| and |release|, also used in various other places throughout the
 # built documents.
@@ -67,13 +85,6 @@ add_module_names = True
 # The name of the Pygments (syntax highlighting) style to use.
 pygments_style = 'sphinx'
 
-# NOTE(cinerama): mock out nova modules so docs can build without warnings
-import mock
-import sys
-MOCK_MODULES = ['nova', 'nova.compute', 'nova.context']
-for module in MOCK_MODULES:
-    sys.modules[module] = mock.Mock()
-
 # A list of glob-style patterns that should be excluded when looking for
 # source files. They are matched against the source file names relative to the
 # source directory, using slashes as directory separators on all platforms.
@@ -88,9 +99,10 @@ suppress_warnings = [ 'app.add_directive']
 
 # The theme to use for HTML and HTML Help pages.  Major themes that come with
 # Sphinx are currently 'default' and 'sphinxdoc'.
-# html_theme_path = ["."]
-# html_theme = '_theme'
-# html_static_path = ['_static']
+if openstackdocstheme is not None:
+    html_theme = 'openstackdocs'
+else:
+    html_theme = 'default'
 
 # Output file base name for HTML help builder.
 htmlhelp_basename = '%sdoc' % project
