@@ -23,7 +23,6 @@ from oslo_log import log
 from oslo_policy import policy
 
 from ironic.common import exception
-from ironic.common.i18n import _LW
 
 _ENFORCER = None
 CONF = cfg.CONF
@@ -205,6 +204,25 @@ extra_policies = [
                        description='Access IPA ramdisk functions'),
 ]
 
+volume_policies = [
+    policy.RuleDefault('baremetal:volume:get',
+                       'rule:is_admin or rule:is_observer',
+                       description='Retrieve Volume connector and target '
+                                   'records'),
+    policy.RuleDefault('baremetal:volume:create',
+                       'rule:is_admin',
+                       description='Create Volume connector and target '
+                                   'records'),
+    policy.RuleDefault('baremetal:volume:delete',
+                       'rule:is_admin',
+                       description='Delete Volume connetor and target '
+                                   'records'),
+    policy.RuleDefault('baremetal:volume:update',
+                       'rule:is_admin',
+                       description='Update Volume connector and target '
+                                   'records'),
+]
+
 
 def list_policies():
     policies = (default_policies
@@ -213,7 +231,8 @@ def list_policies():
                 + portgroup_policies
                 + chassis_policies
                 + driver_policies
-                + extra_policies)
+                + extra_policies
+                + volume_policies)
     return policies
 
 
@@ -323,10 +342,9 @@ def enforce(rule, target, creds, do_raise=False, exc=None, *args, **kwargs):
     # NOTE(deva): this method is obsoleted by authorize(), but retained for
     # backwards compatibility in case it has been used downstream.
     # It may be removed in the Pike cycle.
-    LOG.warning(_LW(
-        "Deprecation warning: calls to ironic.common.policy.enforce() "
-        "should be replaced with authorize(). This method may be removed "
-        "in a future release."))
+    LOG.warning("Deprecation warning: calls to ironic.common.policy.enforce() "
+                "should be replaced with authorize(). This method may be "
+                "removed in a future release.")
     if CONF.auth_strategy == 'noauth':
         return True
     enforcer = get_enforcer()
