@@ -28,7 +28,7 @@
 # { '<release version>': {
 #       'rpc': '<RPC API version>',
 #       'objects':  {
-#            '<object class name>': '<object version>',
+#            '<object class name>': ['<object version>'],
 #       }
 #    },
 # }
@@ -36,6 +36,14 @@
 # sent over RPC. Notifications/Payloads are not being included here since we
 # don't need to pin them during rolling upgrades.
 #
+# For each object, the versions of that object are listed from latest version
+# to oldest version. This is a list since an object could be in more than one
+# version in a particular release.
+# NOTE(rloo): We need a list, not just the latest version, for the DB queries
+# that filter for objects that are not in particular versions; for more info,
+# see comments after L1128 of
+# https://review.openstack.org/#/c/408556/52/ironic/db/sqlalchemy/api.py.
+#
 # There should always be a 'master' entry that reflects the objects in the
 # master branch.
 #
@@ -44,41 +52,42 @@
 #
 # Just after doing a named release, delete any entries associated with the
 # oldest named release.
+
 RELEASE_MAPPING = {
     '7.0': {
         'rpc': '1.40',
         'objects': {
-            'Node': '1.21',
-            'Conductor': '1.2',
-            'Chassis': '1.3',
-            'Port': '1.6',
-            'Portgroup': '1.3',
-            'VolumeConnector': '1.0',
-            'VolumeTarget': '1.0',
+            'Node': ['1.21'],
+            'Conductor': ['1.2'],
+            'Chassis': ['1.3'],
+            'Port': ['1.6'],
+            'Portgroup': ['1.3'],
+            'VolumeConnector': ['1.0'],
+            'VolumeTarget': ['1.0'],
         }
     },
     '8.0': {
         'rpc': '1.40',
         'objects': {
-            'Node': '1.21',
-            'Conductor': '1.2',
-            'Chassis': '1.3',
-            'Port': '1.6',
-            'Portgroup': '1.3',
-            'VolumeConnector': '1.0',
-            'VolumeTarget': '1.0',
+            'Node': ['1.21'],
+            'Conductor': ['1.2'],
+            'Chassis': ['1.3'],
+            'Port': ['1.6'],
+            'Portgroup': ['1.3'],
+            'VolumeConnector': ['1.0'],
+            'VolumeTarget': ['1.0'],
         }
     },
     'master': {
-        'rpc': '1.40',
+        'rpc': '1.41',
         'objects': {
-            'Node': '1.21',
-            'Conductor': '1.2',
-            'Chassis': '1.3',
-            'Port': '1.6',
-            'Portgroup': '1.3',
-            'VolumeConnector': '1.0',
-            'VolumeTarget': '1.0',
+            'Node': ['1.21'],
+            'Conductor': ['1.2'],
+            'Chassis': ['1.3'],
+            'Port': ['1.7'],
+            'Portgroup': ['1.3'],
+            'VolumeConnector': ['1.0'],
+            'VolumeTarget': ['1.0'],
         }
     },
 }
@@ -96,3 +105,29 @@ RELEASE_MAPPING['ocata'] = RELEASE_MAPPING['7.0']
 
 # List of available versions with named versions first; 'master' is excluded.
 RELEASE_VERSIONS = sorted(set(RELEASE_MAPPING) - {'master'}, reverse=True)
+
+
+def get_object_versions(releases=None, objects=None):
+    """Gets the supported versions for all objects.
+
+    Supported versions are from the RELEASE_MAPPINGs.
+
+    :param releases: a list of release names; if empty/None, versions from all
+                     releases are returned (the default).
+    :param objects: a list of names of objects of interest. If empty/None,
+                    versions of all objects are returned (the default).
+
+    :returns: a dictionary where the key is the object name and the value is
+              a set of supported versions.
+    """
+    if not releases:
+        releases = list(RELEASE_MAPPING)
+
+    versions = {}
+    for release in releases:
+        object_mapping = RELEASE_MAPPING[release]['objects']
+        for obj, version_list in object_mapping.items():
+            if not objects or obj in objects:
+                versions.setdefault(obj, set()).update(version_list)
+
+    return versions
