@@ -1,9 +1,5 @@
 # Copyright 2013,2014 Cray Inc
 #
-# Authors: David Hewson <dhewson@cray.com>
-#          Stig Telfer <stelfer@cray.com>
-#          Mark Goddard <mgoddard@cray.com>
-#
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -30,7 +26,6 @@ models.
 import abc
 import time
 
-from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_service import loopingcall
 from oslo_utils import importutils
@@ -38,10 +33,10 @@ import six
 
 from ironic.common import exception
 from ironic.common.i18n import _
-from ironic.common.i18n import _LW
 from ironic.common import states
 from ironic.common import utils
 from ironic.conductor import task_manager
+from ironic.conf import CONF
 from ironic.drivers import base
 
 pysnmp = importutils.try_import('pysnmp')
@@ -54,24 +49,8 @@ else:
     snmp_error = None
     rfc1902 = None
 
-opts = [
-    cfg.IntOpt('power_timeout',
-               default=10,
-               help=_('Seconds to wait for power action to be completed')),
-    # NOTE(yuriyz): some of SNMP-enabled hardware have own options for pause
-    # between off and on. This option guarantees minimal value.
-    cfg.IntOpt('reboot_delay',
-               default=0,
-               min=0,
-               help=_('Time (in seconds) to sleep between when rebooting '
-                      '(powering off and on again)'))
-]
-
 LOG = logging.getLogger(__name__)
 
-CONF = cfg.CONF
-CONF.register_opts(opts, group='snmp')
-
 
 SNMP_V1 = '1'
 SNMP_V2C = '2c'
@@ -386,7 +365,7 @@ class SNMPDriverSimple(SNMPDriverBase):
 
         :returns: Power state object OID as a tuple of integers.
         """
-        outlet = int(self.snmp_info['outlet'])
+        outlet = self.snmp_info['outlet']
         return self.oid_enterprise + self.oid_device + (outlet,)
 
     def _snmp_power_state(self):
@@ -398,8 +377,8 @@ class SNMPDriverSimple(SNMPDriverBase):
         elif state == self.value_power_off:
             power_state = states.POWER_OFF
         else:
-            LOG.warning(_LW("SNMP PDU %(addr)s outlet %(outlet)s: "
-                            "unrecognised power state %(state)s."),
+            LOG.warning("SNMP PDU %(addr)s outlet %(outlet)s: "
+                        "unrecognised power state %(state)s.",
                         {'addr': self.snmp_info['address'],
                          'outlet': self.snmp_info['outlet'],
                          'state': state})
@@ -432,7 +411,7 @@ class SNMPDriverAten(SNMPDriverSimple):
 
         :returns: Power state object OID as a tuple of integers.
         """
-        outlet = int(self.snmp_info['outlet'])
+        outlet = self.snmp_info['outlet']
         return self.oid_enterprise + self.oid_device + (outlet, 0,)
 
 
@@ -551,7 +530,7 @@ class SNMPDriverEatonPower(SNMPDriverBase):
             integers.
         :returns: The full OID as a tuple of integers.
         """
-        outlet = int(self.snmp_info['outlet'])
+        outlet = self.snmp_info['outlet']
         return self.oid_base + oid + (outlet,)
 
     def _snmp_power_state(self):
@@ -564,8 +543,8 @@ class SNMPDriverEatonPower(SNMPDriverBase):
         elif state in (self.status_off, self.status_pending_on):
             power_state = states.POWER_OFF
         else:
-            LOG.warning(_LW("Eaton Power SNMP PDU %(addr)s outlet %(outlet)s: "
-                            "unrecognised power state %(state)s."),
+            LOG.warning("Eaton Power SNMP PDU %(addr)s outlet %(outlet)s: "
+                        "unrecognised power state %(state)s.",
                         {'addr': self.snmp_info['address'],
                          'outlet': self.snmp_info['outlet'],
                          'state': state})
@@ -618,7 +597,7 @@ def _parse_driver_info(node):
     snmp_info = {}
 
     # Validate PDU driver type
-    snmp_info['driver'] = info.get('snmp_driver')
+    snmp_info['driver'] = info['snmp_driver']
     if snmp_info['driver'] not in DRIVER_CLASSES:
         raise exception.InvalidParameterValue(_(
             "SNMPPowerDriver: unknown driver: '%s'") % snmp_info['driver'])
@@ -654,8 +633,14 @@ def _parse_driver_info(node):
         snmp_info['security'] = info.get('snmp_security')
 
     # Target PDU IP address and power outlet identification
-    snmp_info['address'] = info.get('snmp_address')
-    snmp_info['outlet'] = info.get('snmp_outlet')
+    snmp_info['address'] = info['snmp_address']
+    outlet = info['snmp_outlet']
+    try:
+        snmp_info['outlet'] = int(outlet)
+    except ValueError:
+        raise exception.InvalidParameterValue(_(
+            "SNMPPowerDriver: PDU power outlet index is not an integer: %s")
+            % outlet)
 
     return snmp_info
 
