@@ -33,8 +33,8 @@ from ironic.conductor import manager as conductor_manager
 from ironic.conductor import rpcapi as conductor_rpcapi
 from ironic import objects
 from ironic.tests import base as tests_base
-from ironic.tests.unit.db import base
-from ironic.tests.unit.db import utils as dbutils
+from ironic.tests.unit.db import base as db_base
+from ironic.tests.unit.db import utils as db_utils
 
 CONF = cfg.CONF
 
@@ -56,21 +56,20 @@ class ConductorRPCAPITestCase(tests_base.TestCase):
     @mock.patch('ironic.common.rpc.get_client')
     def test_version_capped(self, mock_get_client, mock_release_mapping):
         CONF.set_override('pin_release_version',
-                          release_mappings.RELEASE_VERSIONS[0],
-                          enforce_type=True)
+                          release_mappings.RELEASE_VERSIONS[0])
         mock_release_mapping.get.return_value = {'rpc': '3'}
         conductor_rpcapi.ConductorAPI()
         self.assertEqual('3', mock_get_client.call_args[1]['version_cap'])
 
 
-class RPCAPITestCase(base.DbTestCase):
+class RPCAPITestCase(db_base.DbTestCase):
 
     def setUp(self):
         super(RPCAPITestCase, self).setUp()
-        self.fake_node = dbutils.get_test_node(driver='fake-driver')
+        self.fake_node = db_utils.get_test_node(driver='fake-driver')
         self.fake_node_obj = objects.Node._from_db_object(
-            objects.Node(self.context), self.fake_node)
-        self.fake_portgroup = dbutils.get_test_portgroup()
+            self.context, objects.Node(), self.fake_node)
+        self.fake_portgroup = db_utils.get_test_portgroup()
 
     def test_serialized_instance_has_uuid(self):
         self.assertIn('uuid', self.fake_node)
@@ -147,6 +146,21 @@ class RPCAPITestCase(base.DbTestCase):
         self.assertEqual('fake-topic.fake-host',
                          rpcapi.get_topic_for_driver('fake-driver'))
 
+    def _test_can_send_create_port(self, can_send):
+        rpcapi = conductor_rpcapi.ConductorAPI(topic='fake-topic')
+        with mock.patch.object(rpcapi.client,
+                               "can_send_version") as mock_can_send_version:
+            mock_can_send_version.return_value = can_send
+            result = rpcapi.can_send_create_port()
+            self.assertEqual(can_send, result)
+            mock_can_send_version.assert_called_once_with("1.41")
+
+    def test_can_send_create_port_True(self):
+        self._test_can_send_create_port(True)
+
+    def test_can_send_create_port_False(self):
+        self._test_can_send_create_port(False)
+
     def _test_rpcapi(self, method, rpc_method, **kwargs):
         rpcapi = conductor_rpcapi.ConductorAPI(topic='fake-topic')
 
@@ -266,8 +280,15 @@ class RPCAPITestCase(base.DbTestCase):
                           node_id=self.fake_node['uuid'],
                           enabled=True)
 
+    def test_create_port(self):
+        fake_port = db_utils.get_test_port()
+        self._test_rpcapi('create_port',
+                          'call',
+                          version='1.41',
+                          port_obj=fake_port)
+
     def test_update_port(self):
-        fake_port = dbutils.get_test_port()
+        fake_port = db_utils.get_test_port()
         self._test_rpcapi('update_port',
                           'call',
                           version='1.13',
@@ -425,14 +446,14 @@ class RPCAPITestCase(base.DbTestCase):
                           version='1.34')
 
     def test_destroy_volume_connector(self):
-        fake_volume_connector = dbutils.get_test_volume_connector()
+        fake_volume_connector = db_utils.get_test_volume_connector()
         self._test_rpcapi('destroy_volume_connector',
                           'call',
                           version='1.35',
                           connector=fake_volume_connector)
 
     def test_update_volume_connector(self):
-        fake_volume_connector = dbutils.get_test_volume_connector()
+        fake_volume_connector = db_utils.get_test_volume_connector()
         self._test_rpcapi('update_volume_connector',
                           'call',
                           version='1.35',
@@ -445,14 +466,14 @@ class RPCAPITestCase(base.DbTestCase):
                           node_obj=self.fake_node)
 
     def test_destroy_volume_target(self):
-        fake_volume_target = dbutils.get_test_volume_target()
+        fake_volume_target = db_utils.get_test_volume_target()
         self._test_rpcapi('destroy_volume_target',
                           'call',
                           version='1.37',
                           target=fake_volume_target)
 
     def test_update_volume_target(self):
-        fake_volume_target = dbutils.get_test_volume_target()
+        fake_volume_target = db_utils.get_test_volume_target()
         self._test_rpcapi('update_volume_target',
                           'call',
                           version='1.37',
